@@ -1,5 +1,6 @@
 import os
 import sys
+import dotenv
 
 
 # NOTE: Global constants
@@ -15,6 +16,10 @@ VERY_SHORT_WAIT = [0, 1]
 LONG_WAIT = [20, 40]
 WIDE_WAIT = [1, 10]
 PASTE_PERCENTAGE = 50
+CHANGED_PASSWORD_SEPARATOR = '::::'
+PASSWORD_LENGTH = 25
+ACCOUNT_DISABLED_MESSAGE = 'Account disabled'
+ACCOUNT_VERIFICATION_MESSAGE = 'Account required verification steps'
 
 
 def resource_path(relative_path):
@@ -28,11 +33,12 @@ def resource_path(relative_path):
 
 # NOTE: Configuration
 CWD = resource_path("")
-CONFIG_FOLDER = resource_path("config")
-env_location = os.path.join(CONFIG_FOLDER, '.env_test')
 
 TEMP_FOLDER = resource_path("temp")
 os.makedirs(TEMP_FOLDER, exist_ok=True)
 LOG_FILE = os.path.join(TEMP_FOLDER, 'output.log')
 PROFILE_FOLDER = os.path.join(TEMP_FOLDER, 'profiles')
 PATCHED_DRIVER = os.path.join(TEMP_FOLDER, 'chromedriver.exe')
+CHANGED_EMAILS_FILE = os.path.join(TEMP_FOLDER, 'changed_emails.log')
+FALSE_EMAIL_FILE = os.path.join(TEMP_FOLDER, 'false_email.log')
+PROXY_FOLDER = os.path.join(TEMP_FOLDER, 'proxy')
