@@ -1,7 +1,7 @@
 import random
 import math
-
-from login_gmail_selenium.common import constant as Constant
+import os
+import login_gmail_selenium.common.constant as Constant
 from selenium.webdriver.common.keys import Keys
 from selenium.common.exceptions import TimeoutException, NoSuchElementException
 from selenium.webdriver.common.by import By
@@ -9,6 +9,8 @@ from time import sleep
 from random import randint, uniform
 import selenium.webdriver.support.expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
+import secrets
+import string
 
 
 def sleep_for(period):
@@ -45,6 +47,7 @@ def type_text(driver, text, xpath, custom_enter=None, paste_text=Constant.PASTE_
                 sleep_for(Constant.SHORT_WAIT)
                 input_keyword.clear()
                 input_keyword.send_keys(text)
+
             execute_with_retry(driver, retry_with_script)
         else:
             # TODO: need handling, still meet this case often
@@ -63,6 +66,7 @@ def ensure_click(driver, xpath, retry=Constant.RETRY, refresh=False, script=None
 
         def click_search():
             driver.find_element(By.XPATH, xpath).click()
+
         execute_with_retry(driver, click_search, retry=retry, refresh=refresh)
 
     except NoSuchElementException:
@@ -115,3 +119,31 @@ def ensure_find_element(driver, xpath):
         return driver.find_element(By.XPATH, xpath)
 
     return execute_with_retry(driver, get_element, with_result=True)
+
+
+def get_version(path='C:\Program Files\Google\Chrome\Application'):
+    """
+
+    Args:
+       path: link to Chrome Application
+    """
+    try:
+        sub_folders = [f.name for f in os.scandir(path) if f.is_dir()]
+        for folder in sub_folders:
+            version = folder.split('.')[0]
+            if version.isnumeric():
+                bit = 1
+                return version
+    except (Exception, ValueError):
+        return 0
+
+
+def create_random_password():
+    letters = string.ascii_letters
+    digits = string.digits
+    alphabet = letters + digits
+    pwd_length = Constant.PASSWORD_LENGTH
+    pwd = ''
+    for i in range(pwd_length):
+        pwd += ''.join(secrets.choice(alphabet))
+    return pwd
